@@ -1,5 +1,5 @@
 use clap::ArgMatches;
 
 pub struct Configurator {
-    pub cli_args: ArgMatches<'static>,
+    pub args: ArgMatches,
 }
